Stan Math Library: stan/math/prim/mat/fun/unit_vector_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
unit_vector_constrain.hpp File Reference
`#include <stan/math/prim/arr/err/check_nonzero_size.hpp>`
`#include <stan/math/prim/mat/err/check_vector.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/dot_self.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/err/check_positive_finite.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R, int C>
Eigen::Matrix< T, R, C > | stan::math::unit_vector_constrain (const Eigen::Matrix< T, R, C > &y)
| Return the unit length vector corresponding to the free vector y. More...
template<typename T , int R, int C>
Eigen::Matrix< T, R, C > | stan::math::unit_vector_constrain (const Eigen::Matrix< T, R, C > &y, T &lp)
| Return the unit length vector corresponding to the free vector y. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.